@@ -88,5 +88,9 @@ def get_image_size(context, instance):
             width = instance.image.width
         except:
             width = 100
-    height = int(float(width) / instance.get_aspect_ratio())
-    return (u'%sx%s' % (width, height), width, height)
\ No newline at end of file
+    try:
+        width = int(float(width))
+    except ValueError:
+        width = 100
+    height = int(round(float(width) / instance.get_aspect_ratio()))
+    return (u'%dx%d' % (width, height), width, height)
